@@ -213,10 +213,13 @@ func TestTooManyMX(t *testing.T) {
 		{Host: "h3", Pref: 30}, {Host: "h4", Pref: 40},
 		{Host: "h5", Pref: 50}, {Host: "h5", Pref: 60},
 	}
-	mxs, err := lookupMXs(tr, "domain")
+	mxs, err, perm := lookupMXs(tr, "domain")
 	if err != nil {
 		t.Fatalf("unexpected error: %v", err)
 	}
+	if perm != true {
+		t.Fatalf("expected perm == true")
+	}
 	if len(mxs) != 5 {
 		t.Errorf("expected len(mxs) == 5, got: %v", mxs)
 	}
@@ -230,10 +233,13 @@ func TestFallbackToA(t *testing.T) {
 		IsTemporary: false,
 	}
 
-	mxs, err := lookupMXs(tr, "domain")
+	mxs, err, perm := lookupMXs(tr, "domain")
 	if err != nil {
 		t.Fatalf("unexpected error: %v", err)
 	}
+	if perm != true {
+		t.Fatalf("expected perm == true")
+	}
 	if !(len(mxs) == 1 && mxs[0] == "domain") {
 		t.Errorf("expected mxs == [domain], got: %v", mxs)
 	}
@@ -247,10 +253,13 @@ func TestTemporaryDNSerror(t *testing.T) {
 		IsTemporary: true,
 	}
 
-	mxs, err := lookupMXs(tr, "domain")
+	mxs, err, perm := lookupMXs(tr, "domain")
 	if !(mxs == nil && err == testMXErr["domain"]) {
 		t.Errorf("expected mxs == nil, err == test error, got: %v, %v", mxs, err)
 	}
+	if perm != false {
+		t.Errorf("expected perm == false")
+	}
 }
 
 func TestMXLookupError(t *testing.T) {
@@ -258,19 +267,25 @@ func TestMXLookupError(t *testing.T) {
 	testMX["domain"] = nil
 	testMXErr["domain"] = fmt.Errorf("test error")
 
-	mxs, err := lookupMXs(tr, "domain")
+	mxs, err, perm := lookupMXs(tr, "domain")
 	if !(mxs == nil && err == testMXErr["domain"]) {
 		t.Errorf("expected mxs == nil, err == test error, got: %v, %v", mxs, err)
 	}
+	if perm != true {
+		t.Fatalf("expected perm == true")
+	}
 }
 
 func TestLookupInvalidDomain(t *testing.T) {
 	tr := trace.New("test", "test")
 
-	mxs, err := lookupMXs(tr, invalidDomain)
+	mxs, err, perm := lookupMXs(tr, invalidDomain)
 	if !(mxs == nil && err != nil) {
 		t.Errorf("expected err != nil, got: %v, %v", mxs, err)
 	}
+	if perm != true {
+		t.Fatalf("expected perm == true")
+	}
 }
 
 // TODO: Test STARTTLS negotiation.
